@@ -43,7 +43,7 @@ struct RfbClient::Private
 RfbClient::RfbClient(rfbClientPtr client, QObject* parent)
     : QObject(parent), d(new Private(client))
 {
-    d->remoteAddressString = peerAddress(d->client->sock) + ':' +
+    d->remoteAddressString = peerAddress(d->client->sock) + QLatin1Char(':') +
                              QString::number(peerPort(d->client->sock));
 
     d->notifier = new QSocketNotifier(client->sock, QSocketNotifier::Read, this);
@@ -221,10 +221,10 @@ bool PendingRfbClient::vncAuthCheckPassword(const QByteArray& password, const QB
     bzero(passwd, MAXPWLEN);
 
     if (!password.isEmpty()) {
-        strncpy(passwd, password,
+        strncpy(passwd, password.constData(),
                 (MAXPWLEN <= password.size()) ? MAXPWLEN : password.size());
     }
 
     rfbEncryptBytes(challenge, passwd);
-    return memcmp(challenge, encryptedPassword, encryptedPassword.size()) == 0;
+    return memcmp(challenge, encryptedPassword.constData(), encryptedPassword.size()) == 0;
 }
